.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`metrics`
======================
.. automodule:: skimage.metrics

.. currentmodule:: skimage.metrics
.. autosummary::

   skimage.metrics.adapted_rand_error
   skimage.metrics.contingency_table
   skimage.metrics.mean_squared_error
   skimage.metrics.normalized_root_mse
   skimage.metrics.peak_signal_noise_ratio
   skimage.metrics.structural_similarity
   skimage.metrics.variation_of_information



adapted_rand_error
------------------

.. autofunction:: skimage.metrics.adapted_rand_error


.. include:: skimage.metrics.adapted_rand_error.examples

contingency_table
-----------------

.. autofunction:: skimage.metrics.contingency_table


.. include:: skimage.metrics.contingency_table.examples

mean_squared_error
------------------

.. autofunction:: skimage.metrics.mean_squared_error


.. include:: skimage.metrics.mean_squared_error.examples

normalized_root_mse
-------------------

.. autofunction:: skimage.metrics.normalized_root_mse


.. include:: skimage.metrics.normalized_root_mse.examples

peak_signal_noise_ratio
-----------------------

.. autofunction:: skimage.metrics.peak_signal_noise_ratio


.. include:: skimage.metrics.peak_signal_noise_ratio.examples

structural_similarity
---------------------

.. autofunction:: skimage.metrics.structural_similarity


.. include:: skimage.metrics.structural_similarity.examples

variation_of_information
------------------------

.. autofunction:: skimage.metrics.variation_of_information


.. include:: skimage.metrics.variation_of_information.examples

